.. _user:

==========
User Guide
==========

.. mdinclude:: ../../../README.md
   :start-line: 9

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   Installation <install>
   Running workflows <running-workflows>
   Fireworks integration <fireworks>
   Codes <codes/index>

.. toctree::
   :hidden:

   changelog
   contributors
   contributing
   license
